@@ -34,11 +34,11 @@ class Dialog_Disklabel : public Gtk::Dialog
 {
 public:
 	Dialog_Disklabel( const Device & device ) ;
+	~Dialog_Disklabel();
 
 	Glib::ustring Get_Disklabel( ) ;
 	
 private:
-	Gtk::Image image ;
 	Gtk::ComboBoxText combo_labeltypes ;
 	std::vector<Glib::ustring> labeltypes ;
 };
