@@ -20,9 +20,8 @@
 #include "Partition.h"
 #include "i18n.h"
 
+#include <glibmm/ustring.h>
 #include <gtkmm/dialog.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/table.h>
 #include <gtkmm/entry.h>
 
 namespace GParted
