@@ -17,7 +17,9 @@
 #ifndef GPARTED_OPERATIONNAMEPARTITION_H
 #define GPARTED_OPERATIONNAMEPARTITION_H
 
-#include "../include/Operation.h"
+#include "Operation.h"
+#include "Partition.h"
+#include "PartitionVector.h"
 
 namespace GParted
 {
@@ -28,10 +30,14 @@ public:
 	OperationNamePartition( const Device & device,
 	                        const Partition & partition_orig,
 	                        const Partition & partition_new );
+	virtual ~OperationNamePartition();
 
-	void apply_to_visual( std::vector<Partition> & partitions );
+	void apply_to_visual( PartitionVector & partitions );
 
 private:
+	OperationNamePartition( const OperationNamePartition & src );              // Not implemented copy constructor
+	OperationNamePartition & operator=( const OperationNamePartition & rhs );  // Not implemented copy assignment operator
+
 	void create_description();
 	bool merge_operations( const Operation & candidate );
 };
