@@ -52,7 +52,7 @@ DialogFeatures::DialogFeatures()
 	Gtk::TreeView::Column *col;
 	liststore_filesystems = Gtk::ListStore::create( treeview_filesystems_columns );
 	treeview_filesystems .set_model( liststore_filesystems );
-	treeview_filesystems .append_column( _("File System"), treeview_filesystems_columns .filesystem );
+	treeview_filesystems.append_column(_("File System"), treeview_filesystems_columns.fsname);
 	treeview_filesystems .append_column( _("Create"), treeview_filesystems_columns .create );
 	col = manage( new Gtk::TreeView::Column( _("Grow") ) );
 	col ->pack_start( treeview_filesystems_columns .grow, false );
@@ -65,7 +65,10 @@ DialogFeatures::DialogFeatures()
 	treeview_filesystems .append_column( _("Move"), treeview_filesystems_columns .move );
 	treeview_filesystems .append_column( _("Copy"), treeview_filesystems_columns .copy );
 	treeview_filesystems .append_column( _("Check"), treeview_filesystems_columns .check );
-	treeview_filesystems .append_column( _("Label"), treeview_filesystems_columns .label );
+	col = manage(new Gtk::TreeView::Column(_("Label")));
+	col->pack_start(treeview_filesystems_columns.label, false);
+	col->pack_start(treeview_filesystems_columns.online_label, false);
+	treeview_filesystems.append_column(*col);
 	treeview_filesystems .append_column( _("UUID"), treeview_filesystems_columns .uuid );
 	treeview_filesystems .append_column( _("Required Software"), treeview_filesystems_columns .software );
 	treeview_filesystems .get_selection() ->set_mode( Gtk::SELECTION_NONE );
@@ -170,14 +173,14 @@ void DialogFeatures::load_filesystems(const std::vector<FS>& fss)
 	// Fill the features chart with fully supported file systems.
 	for (unsigned i = 0; i < fss.size(); i++)
 	{
-		if (GParted_Core::supported_filesystem(fss[i].filesystem))
+		if (GParted_Core::supported_filesystem(fss[i].fstype))
 			load_one_filesystem(fss[i]);
 	}
 
 	// Find and add "other" at the end, for all the basic supported file systems.
 	for (unsigned i = 0; i < fss.size(); i++)
 	{
-		if (fss[i].filesystem == FS_OTHER)
+		if (fss[i].fstype == FS_OTHER)
 		{
 			load_one_filesystem(fss[i]);
 			break;
@@ -188,23 +191,25 @@ void DialogFeatures::load_filesystems(const std::vector<FS>& fss)
 
 void DialogFeatures::load_one_filesystem(const FS& fs)
 {
-	treerow = *( liststore_filesystems ->append() );
-	treerow[ treeview_filesystems_columns .filesystem ] = Utils::get_filesystem_string( fs .filesystem ) ;
+	treerow = *(liststore_filesystems->append());
+	treerow[treeview_filesystems_columns.fsname] = Utils::get_filesystem_string(fs.fstype);
 
-	treerow[ treeview_filesystems_columns .create ] = fs .create ? icon_yes : icon_no ; 
-	treerow[ treeview_filesystems_columns .grow ] = fs .grow ? icon_yes : icon_no ; 
-	treerow[ treeview_filesystems_columns .online_grow ] = fs .online_grow ? icon_yes : icon_blank ;
-	treerow[ treeview_filesystems_columns .shrink ] = fs .shrink ? icon_yes : icon_no ; 
-	treerow[ treeview_filesystems_columns .online_shrink ] = fs .online_shrink ? icon_yes : icon_blank ;
-	treerow[ treeview_filesystems_columns .move ] = fs .move ? icon_yes : icon_no ;  
-	treerow[ treeview_filesystems_columns .copy ] = fs .copy ? icon_yes : icon_no ; 
-	treerow[ treeview_filesystems_columns .check ] = fs .check ? icon_yes : icon_no ; 
-	treerow[ treeview_filesystems_columns .label ] = fs .write_label ? icon_yes : icon_no ; 
-	treerow[ treeview_filesystems_columns .uuid ] = fs .write_uuid ? icon_yes : icon_no ;
+	treerow[treeview_filesystems_columns.create       ] = fs.create             ? icon_yes : icon_no;
+	treerow[treeview_filesystems_columns.grow         ] = fs.grow               ? icon_yes : icon_no;
+	treerow[treeview_filesystems_columns.online_grow  ] = fs.online_grow        ? icon_yes : icon_blank;
+	treerow[treeview_filesystems_columns.shrink       ] = fs.shrink             ? icon_yes : icon_no;
+	treerow[treeview_filesystems_columns.online_shrink] = fs.online_shrink      ? icon_yes : icon_blank;
+	treerow[treeview_filesystems_columns.move         ] = fs.move               ? icon_yes : icon_no;
+	treerow[treeview_filesystems_columns.copy         ] = fs.copy               ? icon_yes : icon_no;
+	treerow[treeview_filesystems_columns.check        ] = fs.check              ? icon_yes : icon_no;
+	treerow[treeview_filesystems_columns.label        ] = fs.write_label        ? icon_yes : icon_no;
+	treerow[treeview_filesystems_columns.online_label ] = fs.online_write_label ? icon_yes : icon_blank;
+	treerow[treeview_filesystems_columns.uuid         ] = fs.write_uuid         ? icon_yes : icon_no;
 
-	treerow[ treeview_filesystems_columns .software ] = Utils::get_filesystem_software( fs .filesystem ) ;
+	treerow[treeview_filesystems_columns.software] = Utils::get_filesystem_software(fs.fstype);
 }
 
+
 DialogFeatures::~DialogFeatures() 
 {
 }
