@@ -143,13 +143,13 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 		     ev ->x <= X_START &&
 		     ev ->y >= 5 &&
 		     ev ->y <= 45 ) 
-			drawingarea .get_parent_window() ->set_cursor( *cursor_resize ) ;
+			drawingarea.get_parent_window()->set_cursor(cursor_resize);
 		//right grip
 		else if (  ev ->x >= X_END &&
 			   ev ->x <= X_END + GRIPPER &&
 			   ev ->y >= 5 &&
 			   ev ->y <= 45 ) 
-			drawingarea .get_parent_window() ->set_cursor( *cursor_resize ) ;
+			drawingarea.get_parent_window()->set_cursor(cursor_resize);
 		//normal pointer
 		else 
 			drawingarea .get_parent_window() ->set_cursor() ;		
@@ -162,24 +162,24 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 void Frame_Resizer_Extended::draw_partition(const Cairo::RefPtr<Cairo::Context>& cr)
 {
 	// Background color
-	Gdk::Cairo::set_source_color(cr, color_background);
+	Gdk::Cairo::set_source_rgba(cr, color_background);
 	cr->rectangle(0, 0, 536, 50);
 	cr->fill();
 
 	// The two rectangles on each side of the partition
-	Gdk::Cairo::set_source_color(cr, color_arrow_rectangle);
+	Gdk::Cairo::set_source_rgba(cr, color_arrow_rectangle);
 	cr->rectangle(0, 0, 10, 50);
 	cr->fill();
 	cr->rectangle(526, 0, 10, 50);
 	cr->fill();
 
 	// Used
-	Gdk::Cairo::set_source_color(cr, color_used);
+	Gdk::Cairo::set_source_rgba(cr, color_used);
 	cr->rectangle(USED_START + BORDER, BORDER, USED, 34);
 	cr->fill();
 
 	// Partition
-	Gdk::Cairo::set_source_color(cr, color_partition);
+	Gdk::Cairo::set_source_rgba(cr, color_partition);
 	for( short t = 0; t < 9 ; t++ )
 	{
 		cr->rectangle(X_START + t + 0.5, t + 0.5, X_END - X_START - t*2, 50 - t*2);
