@@ -148,87 +148,88 @@ FS ext2::get_filesystem_support()
 	return fs ;
 }
 
-void ext2::set_used_sectors( Partition & partition ) 
+
+void ext2::set_used_sectors(Partition& partition)
 {
 	// Called when file system is unmounted *and* when mounted.  Always read
 	// the file system size from the on disk superblock using dumpe2fs to
 	// avoid overhead subtraction.  When mounted read the free space from
 	// the kernel via the statvfs() system call.  When unmounted read the
 	// free space using resize2fs itself falling back to using dumpe2fs.
-	if ( ! Utils::execute_command( "dumpe2fs -h " + Glib::shell_quote( partition.get_path() ),
-	                               output, error, true )                                       )
+	exit_status = Utils::execute_command("dumpe2fs -h " + Glib::shell_quote(partition.get_path()),
+	                                     output, error, true);
+	if (exit_status != 0)
 	{
-		Glib::ustring::size_type index = output.find( "Block count:" );
-		if ( index >= output .length() ||
-		     sscanf( output.substr( index ).c_str(), "Block count: %lld", &T ) != 1 )
-			T = -1 ;
+		if (! output.empty())
+			partition.push_back_message(output);
+		if (! error.empty())
+			partition.push_back_message(error);
+		return;
+	}
 
-		index = output .find( "Block size:" ) ;
-		if ( index >= output.length() || 
-		     sscanf( output.substr( index ).c_str(), "Block size: %lld", &S ) != 1 )
-			S = -1 ;
+	long long block_count = -1;
+	Glib::ustring::size_type index = output.find("\nBlock count:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "\nBlock count: %lld", &block_count);
 
-		if ( partition .busy )
+	long long block_size = -1;
+	index = output.find("\nBlock size:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "\nBlock size: %lld", &block_size);
+
+	long long free_blocks = -1;
+	if (partition.busy)
+	{
+		Byte_Value ignored;
+		Byte_Value fs_free_bytes;
+		if (Utils::get_mounted_filesystem_usage(partition.get_mountpoint(),
+		                                        ignored, fs_free_bytes, error) == 0)
 		{
-			Byte_Value ignored ;
-			Byte_Value fs_free ;
-			if ( Utils::get_mounted_filesystem_usage( partition .get_mountpoint(),
-			                                          ignored, fs_free, error ) == 0 )
-			{
-				N = fs_free / S;
-			}
-			else
-			{
-				N = -1 ;
-				partition.push_back_message( error );
-			}
+			free_blocks = fs_free_bytes / block_size;
 		}
 		else
 		{
-			// Resize2fs won't shrink a file system smaller than it's own
-			// estimated minimum size, so use that to derive the free space.
-			N = -1;
-			Glib::ustring output2;
-			Glib::ustring error2;
-			if ( ! Utils::execute_command( "resize2fs -P " + Glib::shell_quote( partition.get_path() ),
-			                               output2, error2, true )                                      )
-			{
-				if ( sscanf( output2.c_str(), "Estimated minimum size of the filesystem: %lld", &N ) == 1 )
-					N = T - N;
-			}
-
-			// Resize2fs can fail reporting please run fsck first.  Fall back
-			// to reading dumpe2fs output for free space.
-			if ( N == -1 )
-			{
-				index = output.find( "Free blocks:" );
-				if ( index < output.length() )
-					sscanf( output.substr( index ).c_str(), "Free blocks: %lld", &N );
-			}
-
-			if ( N == -1 && ! error2.empty() )
-				partition.push_back_message( error );
-		}
-
-		if ( T > -1 && N > -1 && S > -1 )
-		{
-			T = Utils::round( T * ( S / double(partition.sector_size) ) );
-			N = Utils::round( N * ( S / double(partition.sector_size) ) );
-
-			partition .set_sector_usage( T, N ) ;
-			partition.fs_block_size = S;
+			partition.push_back_message(error);
 		}
 	}
 	else
 	{
-		if ( ! output .empty() )
-			partition.push_back_message( output );
-		
-		if ( ! error .empty() )
-			partition.push_back_message( error );
+		// Resize2fs won't shrink a file system smaller than it's own estimated
+		// minimum size, so use that to derive the free space.
+		Glib::ustring output2;
+		Glib::ustring error2;
+		if (! Utils::execute_command("resize2fs -P " + Glib::shell_quote(partition.get_path()),
+		                             output2, error2, true)                                    )
+		{
+			long long minimum_blocks = -1;
+			sscanf(output2.c_str(), "Estimated minimum size of the filesystem: %lld", &minimum_blocks);
+			if (minimum_blocks > -1)
+				free_blocks = block_count - minimum_blocks;
+		}
+
+		// Resize2fs can fail reporting please run fsck first.  Fall back to
+		// reading dumpe2fs output for free space.
+		if (free_blocks == -1)
+		{
+			index = output.find("\nFree blocks:");
+			if (index < output.length())
+				sscanf(output.substr(index).c_str(), "\nFree blocks: %lld", &free_blocks);
+		}
+
+		if (free_blocks == -1 && error2.empty())
+			partition.push_back_message(error2);
+	}
+
+	if (block_count > -1 && block_size > -1 && free_blocks > -1)
+	{
+		Sector fs_size = block_count * block_size / partition.sector_size;
+		Sector fs_free = free_blocks * block_size / partition.sector_size;
+		partition.set_sector_usage(fs_size, fs_free);
+		partition.fs_block_size = block_size;
 	}
 }
-	
+
+
 void ext2::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "e2label " + Glib::shell_quote( partition.get_path() ),
@@ -297,18 +298,19 @@ bool ext2::create( const Partition & new_partition, OperationDetail & operationd
 	                          static_cast<StreamSlot>( sigc::mem_fun( *this, &ext2::create_progress ) ) );
 }
 
-bool ext2::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
-{
-	Glib::ustring str_temp = "resize2fs -p " + Glib::shell_quote( partition_new.get_path() );
-	
-	if ( ! fill_partition )
-		str_temp += " " + Utils::num_to_str( floor( Utils::sector_to_unit(
-					partition_new .get_sector_length(), partition_new .sector_size, UNIT_KIB ) ) ) + "K";
 
-	return ! execute_command( str_temp, operationdetail, EXEC_CHECK_STATUS|EXEC_PROGRESS_STDOUT,
-	                          static_cast<StreamSlot>( sigc::mem_fun( *this, &ext2::resize_progress ) ) );
+bool ext2::resize(const Partition& partition_new, OperationDetail& operationdetail, bool fill_partition)
+{
+	Glib::ustring size;
+	if ( ! fill_partition )
+		size = " " + Utils::num_to_str(partition_new.get_byte_length() / KIBIBYTE) + "K";
+
+	return ! execute_command("resize2fs -p " + Glib::shell_quote(partition_new.get_path()) + size,
+	                         operationdetail, EXEC_CHECK_STATUS|EXEC_PROGRESS_STDOUT,
+	                         static_cast<StreamSlot>(sigc::mem_fun(*this, &ext2::resize_progress)));
 }
 
+
 bool ext2::check_repair( const Partition & partition, OperationDetail & operationdetail )
 {
 	exit_status = execute_command( "e2fsck -f -y -v -C 0 " + Glib::shell_quote( partition.get_path() ),
