@@ -17,8 +17,12 @@
 
 #include "jfs.h"
 #include "FileSystem.h"
+#include "OperationDetail.h"
 #include "Partition.h"
+#include "Utils.h"
 
+#include <stdio.h>
+#include <glibmm/ustring.h>
 #include <glibmm/miscutils.h>
 #include <glibmm/shell.h>
 
@@ -34,6 +38,7 @@ FS jfs::get_filesystem_support()
 
 	if ( ! Glib::find_program_in_path( "jfs_debugfs" ) .empty() ) {
 		fs.read = FS::EXTERNAL;
+		fs.online_read = FS::EXTERNAL;
 	}
 
 	if ( ! Glib::find_program_in_path( "jfs_tune" ) .empty() ) {
@@ -67,7 +72,6 @@ FS jfs::get_filesystem_support()
 		fs.copy = FS::GPARTED;
 	}
 
-	fs .online_read = FS::GPARTED ;
 #ifdef ENABLE_ONLINE_RESIZE
 	if ( Utils::kernel_version_at_least( 3, 6, 0 ) )
 		fs .online_grow = fs .grow ;
@@ -78,47 +82,98 @@ FS jfs::get_filesystem_support()
 	return fs ;
 }
 
+
 void jfs::set_used_sectors( Partition & partition ) 
 {
-	const Glib::ustring jfs_debug_cmd = "jfs_debugfs " + Glib::shell_quote( partition.get_path() );
-	if ( ! Utils::execute_command( jfs_debug_cmd, "dm\n", output, error, true ) )
+	// Called when the file system is unmounted *and* when mounted.  Always reads the
+	// on disk superblock using jfs_debugfs to accurately calculate the overall size
+	// of the file system.  Read free space from the kernel via statvfs() when mounted
+	// for the up to date figure, and from the on disk Aggregate Disk Map (dmap) when
+	// unmounted.
+	exit_status = Utils::execute_command("jfs_debugfs " + Glib::shell_quote(partition.get_path()),
+	                                     "superblock\nx\ndmap\nx\nquit\n", output, error, true);
+	if (exit_status != 0)
 	{
-		//blocksize
-		Glib::ustring::size_type index = output.find( "Block Size:" );
-		if ( index >= output .length() || 
-		     sscanf( output.substr( index ).c_str(), "Block Size: %lld", &S ) != 1 )
-			S = -1 ;
+		if (! output.empty())
+			partition.push_back_message(output);
+		if (! error.empty())
+			partition.push_back_message(error);
+		return;
+	}
 
-		//total blocks
-		index = output .find( "dn_mapsize:" ) ;
-		if ( index >= output .length() ||
-		     sscanf( output.substr( index ).c_str(), "dn_mapsize: %llx", &T ) != 1 )
-			T = -1 ;
+	// s_size - Aggregate size in device (s_pbsize) blocks
+	long long agg_size = -1;
+	Glib::ustring::size_type index = output.find("s_size:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "s_size: %llx", &agg_size);
 
-		//free blocks
-		index = output .find( "dn_nfree:" ) ;
-		if ( index >= output .length() || 
-		     sscanf( output.substr( index ).c_str(), "dn_nfree: %llx", &N ) != 1 )
-			N = -1 ;
+	// s_bsize - Aggregate block (aka file system allocation) size in bytes
+	long long agg_block_size = -1;
+	index = output.find("s_bsize:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "s_bsize: %lld", &agg_block_size);
 
-		if ( T > -1 && N > -1 && S > -1 )
+	// s_pbsize - Physical (device) block size in bytes
+	long long phys_block_size = -1;
+	index = output.find("s_pbsize:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "s_pbsize: %lld", &phys_block_size);
+
+	// s_logpxd.len - Log (Journal) size in Aggregate (s_bsize) blocks
+	long long log_len = -1;
+	index = output.find("s_logpxd.len:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "s_logpxd.len: %lld", &log_len);
+
+	// s_fsckpxd.len - FSCK Working Space in Aggregate (s_bsize) blocks
+	long long fsck_len = -1;
+	index = output.find("s_fsckpxd.len:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "s_fsckpxd.len: %lld", &fsck_len);
+
+	Sector fs_size_sectors = -1;
+	if (agg_size > -1 && agg_block_size > -1 && phys_block_size > -1 && log_len > -1 && fsck_len > -1)
+	{
+		fs_size_sectors = (  agg_size * phys_block_size
+		                   + log_len  * agg_block_size
+		                   + fsck_len * agg_block_size) / partition.sector_size;
+	}
+
+	Sector fs_free_sectors = -1;
+	if (partition.busy)
+	{
+		Byte_Value ignored;
+		Byte_Value fs_free_bytes;
+		if (Utils::get_mounted_filesystem_usage(partition.get_mountpoint(), ignored, fs_free_bytes, error) != 0)
 		{
-			T = Utils::round( T * ( S / double(partition .sector_size) ) ) ;
-			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
-			partition .set_sector_usage( T, N ) ;
-			partition.fs_block_size = S;
+			partition.push_back_message(error);
+			return;
+		}
+
+		fs_free_sectors = fs_free_bytes / partition.sector_size;
+	}
+	else // (! partition.busy)
+	{
+		// dn_nfree - Number of free (s_bsize) blocks in Aggregate
+		long long free_blocks = -1;
+		index = output.find("dn_nfree:");
+		if (index < output.length())
+			sscanf(output.substr(index).c_str(), "dn_nfree: %llx", &free_blocks);
+
+		if (agg_block_size && free_blocks > -1)
+		{
+			fs_free_sectors = free_blocks * agg_block_size / partition.sector_size;
 		}
 	}
-	else
+
+	if (fs_size_sectors > -1 && fs_free_sectors > -1 && agg_block_size > -1)
 	{
-		if ( ! output .empty() )
-			partition.push_back_message( output );
-		
-		if ( ! error .empty() )
-			partition.push_back_message( error );
+		partition.set_sector_usage(fs_size_sectors, fs_free_sectors);
+		partition.fs_block_size = agg_block_size;
 	}
 }
 
+
 void jfs::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "jfs_tune -l " + Glib::shell_quote( partition.get_path() ),
