@@ -81,44 +81,45 @@ FS reiserfs::get_filesystem_support()
 	return fs ;
 }
 
-void reiserfs::set_used_sectors( Partition & partition ) 
+
+void reiserfs::set_used_sectors(Partition& partition)
 {
-	if ( ! Utils::execute_command( "debugreiserfs " + Glib::shell_quote( partition.get_path() ),
-	                               output, error, true )                                         )
+	exit_status = Utils::execute_command("debugreiserfs " + Glib::shell_quote(partition.get_path()),
+	                                     output, error, true);
+	if (exit_status != 0)
 	{
-		Glib::ustring::size_type index = output.find( "Count of blocks on the device:" );
-		if ( index >= output .length() ||
-		     sscanf( output.substr( index ).c_str(), "Count of blocks on the device: %lld", &T ) != 1 )
-			T = -1 ;
-
-		index = output .find( "Blocksize:" ) ;
-		if ( index >= output .length() || 
-		     sscanf( output.substr( index ).c_str(), "Blocksize: %lld", &S ) != 1 )
-			S = -1 ;
-
-		index = output .find( ":", output .find( "Free blocks" ) ) +1 ;
-		if ( index >= output .length() ||
-		     sscanf( output.substr( index ).c_str(), "%lld", &N ) != 1 )
-			N = -1 ;
-
-		if ( T > -1 && N > -1 && S > -1 )
-		{
-			T = Utils::round( T * ( S / double(partition .sector_size) ) ) ;
-			N = Utils::round( N * ( S / double(partition .sector_size) ) ) ;
-			partition .set_sector_usage( T, N ) ;
-			partition.fs_block_size = S;
-		}
+		if (! output.empty())
+			partition.push_back_message(output);
+		if (! error.empty())
+			partition.push_back_message(error);
+		return;
 	}
-	else
+
+	long long block_count = -1;
+	Glib::ustring::size_type index = output.find("\nCount of blocks on the device:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "\nCount of blocks on the device: %lld", &block_count);
+
+	long long block_size = -1;
+	index = output.find("\nBlocksize:");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "\nBlocksize: %lld", &block_size);
+
+	long long free_blocks = -1;
+	index = output.find("\nFree blocks");
+	if (index < output.length())
+		sscanf(output.substr(index).c_str(), "\nFree blocks%*[^:]: %lld", &free_blocks);
+
+	if (block_count > -1 && block_size > -1 && free_blocks > -1)
 	{
-		if ( ! output .empty() )
-			partition.push_back_message( output );
-		
-		if ( ! error .empty() )
-			partition.push_back_message( error );
+		Sector fs_size = block_count * block_size / partition.sector_size;
+		Sector fs_free = free_blocks * block_size / partition.sector_size;
+		partition.set_sector_usage(fs_size, fs_free);
+		partition.fs_block_size = block_size;
 	}
 }
 
+
 void reiserfs::read_label( Partition & partition )
 {
 	if ( ! Utils::execute_command( "debugreiserfs " + Glib::shell_quote( partition.get_path() ),
@@ -177,10 +178,7 @@ bool reiserfs::resize( const Partition & partition_new, OperationDetail & operat
 { 
 	Glib::ustring size = "" ;
 	if ( ! fill_partition )
-	{
-		size = " -s " + Utils::num_to_str( floor( Utils::sector_to_unit(
-		                   partition_new .get_sector_length(), partition_new .sector_size, UNIT_BYTE ) ) ) ;
-	}
+		size = " -s " + Utils::num_to_str(partition_new.get_byte_length());
 	const Glib::ustring resize_cmd = "echo y | resize_reiserfs" + size +
 	                                 " " + Glib::shell_quote( partition_new.get_path() );
 	exit_status = execute_command( "sh -c " + Glib::shell_quote( resize_cmd ), operationdetail );
